PartialOrd

Trait PartialOrd 

1.0.0 (const: unstable) · Source
pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>
where Rhs: ?Sized,
{ // Required method fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>; // Provided methods fn lt(&self, other: &Rhs) -> bool { ... } fn le(&self, other: &Rhs) -> bool { ... } fn gt(&self, other: &Rhs) -> bool { ... } fn ge(&self, other: &Rhs) -> bool { ... } }
Trait for types that form a partial order.

The lt, le, gt, and ge methods of this trait can be called using the <, <=, >, and >= operators, respectively.

This trait should only contain the comparison logic for a type if one plans on only implementing PartialOrd but not Ord. Otherwise the comparison logic should be in Ord and this trait implemented with Some(self.cmp(other)).

The methods of this trait must be consistent with each other and with those of PartialEq. The following conditions must hold:

  1. a == b if and only if partial_cmp(a, b) == Some(Equal).
  2. a < b if and only if partial_cmp(a, b) == Some(Less)
  3. a > b if and only if partial_cmp(a, b) == Some(Greater)
  4. a <= b if and only if a < b || a == b
  5. a >= b if and only if a > b || a == b
  6. a != b if and only if !(a == b).

Conditions 2–5 above are ensured by the default implementation. Condition 6 is already ensured by PartialEq.

If Ord is also implemented for Self and Rhs, it must also be consistent with partial_cmp (see the documentation of that trait for the exact requirements). It’s easy to accidentally make them disagree by deriving some of the traits and manually implementing others.

The comparison relations must satisfy the following conditions (for all a, b, c of type A, B, C):

  • Transitivity: if A: PartialOrd<B> and B: PartialOrd<C> and A: PartialOrd<C>, then a < b and b < c implies a < c. The same must hold for both == and >. This must also work for longer chains, such as when A: PartialOrd<B>, B: PartialOrd<C>, C: PartialOrd<D>, and A: PartialOrd<D> all exist.
  • Duality: if A: PartialOrd<B> and B: PartialOrd<A>, then a < b if and only if b > a.

Note that the B: PartialOrd<A> (dual) and A: PartialOrd<C> (transitive) impls are not forced to exist, but these requirements apply whenever they do exist.

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Cross-crate considerations

Upholding the requirements stated above can become tricky when one crate implements PartialOrd for a type of another crate (i.e., to allow comparing one of its own types with a type from the standard library). The recommendation is to never implement this trait for a foreign type. In other words, such a crate should do impl PartialOrd<ForeignType> for LocalType, but it should not do impl PartialOrd<LocalType> for ForeignType.

This avoids the problem of transitive chains that criss-cross crate boundaries: for all local types T, you may assume that no other crate will add impls that allow comparing T < U. In other words, if other crates add impls that allow building longer transitive chains U1 < ... < T < V1 < ..., then all the types that appear to the right of T must be types that the crate defining T already knows about. This rules out transitive chains where downstream crates can add new impls that “stitch together” comparisons of foreign types in ways that violate transitivity.

Not having such foreign impls also avoids forward compatibility issues where one crate adding more PartialOrd implementations can cause build failures in downstream crates.

Corollaries

The following corollaries follow from the above requirements:

  • irreflexivity of < and >: !(a < a), !(a > a)
  • transitivity of >: if a > b and b > c then a > c
  • duality of partial_cmp: partial_cmp(a, b) == partial_cmp(b, a).map(Ordering::reverse)

Strict and non-strict partial orders

The < and > operators behave according to a strict partial order. However, <= and >= do not behave according to a non-strict partial order. That is because mathematically, a non-strict partial order would require reflexivity, i.e. a <= a would need to be true for every a. This isn’t always the case for types that implement PartialOrd, for example:

let a = f64::NAN;
assert_eq!(a <= a, false);

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are primarily ordered by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

How can I implement PartialOrd?

PartialOrd only requires implementation of the partial_cmp method, with the others generated from default implementations.

However it remains possible to implement the others separately for types which do not have a total order. For example, for floating point numbers, NaN < 0 == false and NaN >= 0 == false (cf. IEEE 754-2008 section 5.11).

PartialOrd requires your type to be PartialEq.

If your type is Ord, you can implement partial_cmp by using cmp:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: u32,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Person {
    fn cmp(&self, other: &Self) -> Ordering {
        self.height.cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

impl Eq for Person {}

You may also find it useful to use partial_cmp on your type’s fields. Here is an example of Person types who have a floating-point height field that is the only field to be used for sorting:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: f64,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        self.height.partial_cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

Examples of incorrect PartialOrd implementations

use std::cmp::Ordering;

#[derive(PartialEq, Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.health.cmp(&other.health))
    }
}

let a = Character {
    health: 10,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};

// Mistake: `PartialEq` and `PartialOrd` disagree with each other.

assert_eq!(a.partial_cmp(&b).unwrap(), Ordering::Equal); // a == b according to `PartialOrd`.
assert_ne!(a, b); // a != b according to `PartialEq`.

Examples

let x: u32 = 0;
let y: u32 = 1;

assert_eq!(x < y, true);
assert_eq!(x.lt(&y), true);

Required Methods

1.0.0 (const: unstable) · Source

fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>

This method returns an ordering between self and other values if one exists.

Examples
use std::cmp::Ordering;

let result = 1.0.partial_cmp(&2.0);
assert_eq!(result, Some(Ordering::Less));

let result = 1.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Equal));

let result = 2.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Greater));

When comparison is impossible:

let result = f64::NAN.partial_cmp(&1.0);
assert_eq!(result, None);

Provided Methods

1.0.0 (const: unstable) · Source

fn lt(&self, other: &Rhs) -> bool

Tests less than (for self and other) and is used by the < operator.

Examples
assert_eq!(1.0 < 1.0, false);
assert_eq!(1.0 < 2.0, true);
assert_eq!(2.0 < 1.0, false);
1.0.0 (const: unstable) · Source

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator.

Examples
assert_eq!(1.0 <= 1.0, true);
assert_eq!(1.0 <= 2.0, true);
assert_eq!(2.0 <= 1.0, false);
1.0.0 (const: unstable) · Source

fn gt(&self, other: &Rhs) -> bool

Tests greater than (for self and other) and is used by the > operator.

Examples
assert_eq!(1.0 > 1.0, false);
assert_eq!(1.0 > 2.0, false);
assert_eq!(2.0 > 1.0, true);
1.0.0 (const: unstable) · Source

fn ge(&self, other: &Rhs) -> bool

Tests greater than or equal to (for self and other) and is used by the >= operator.

Examples
assert_eq!(1.0 >= 1.0, true);
assert_eq!(1.0 >= 2.0, false);
assert_eq!(2.0 >= 1.0, true);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.100.0 (const: unstable) · Source

impl PartialOrd for !

1.0.0 (const: unstable) · Source

impl PartialOrd for ()

Source

impl PartialOrd for Alignment

Source

impl PartialOrd for AsciiChar

Source

impl PartialOrd for Attribute

Source

impl PartialOrd for Attributes

Source

impl PartialOrd for BidiClass

Source

impl PartialOrd for ByteStr

Source

impl PartialOrd for ByteString

Source

impl PartialOrd for Bytes

Source

impl PartialOrd for BytesMut

1.0.0 (const: unstable) · Source

impl PartialOrd for CStr

1.64.0 · Source

impl PartialOrd for CString

Source

impl PartialOrd for CanonicalCombiningClass

Source

impl PartialOrd for CharCase

Source

impl PartialOrd for CharULE

Source

impl PartialOrd for Compress

1.27.0 · Source

impl PartialOrd for CpuidResult

Source

impl PartialOrd for CurrencyType

Source

impl PartialOrd for DataMarkerAttributes

Source

impl PartialOrd for DataMarkerId

Source

impl PartialOrd for DataMarkerIdHash

Source

impl PartialOrd for DataMarkerInfo

Source

impl PartialOrd for DataRequestMetadata

1.3.0 · Source

impl PartialOrd for Duration

Source

impl PartialOrd for EastAsianWidth

Source

impl PartialOrd for Errno

1.0.0 · Source

impl PartialOrd for Error

1.0.0 · Source

impl PartialOrd for ErrorKind

Source

impl PartialOrd for ExtensionType

Source

impl PartialOrd for FieldId

Source

impl PartialOrd for Fields

Source

impl PartialOrd for FipsStatus

Source

impl PartialOrd for GeneralCategory

Source

impl PartialOrd for GeneralCategoryOutOfBoundsError

Source

impl PartialOrd for GeneralCategoryULE

Source

impl PartialOrd for GraphemeClusterBreak

Source

impl PartialOrd for HangulSyllableType

Source

impl PartialOrd for Id

Source

impl PartialOrd for Index8

Source

impl PartialOrd for Index16

Source

impl PartialOrd for Index32

Source

impl PartialOrd for IndicConjunctBreak

Source

impl PartialOrd for IndicSyllabicCategory

1.8.0 · Source

impl PartialOrd for std::time::Instant

Source

impl PartialOrd for tokio::time::instant::Instant

Source

impl PartialOrd for Interest

1.7.0 · Source

impl PartialOrd for IpAddr

1.0.0 (const: unstable) · Source

impl PartialOrd for Ipv4Addr

1.0.0 (const: unstable) · Source

impl PartialOrd for Ipv6Addr

Source

impl PartialOrd for Ipv6MulticastScope

Source

impl PartialOrd for JoiningGroup

Source

impl PartialOrd for JoiningType

Source

impl PartialOrd for icu_locale_core::extensions::transform::key::Key

Source

impl PartialOrd for icu_locale_core::extensions::unicode::key::Key

Source

impl PartialOrd for Keywords

Source

impl PartialOrd for Language

Source

impl PartialOrd for Level

Source

impl PartialOrd for LevelFilter

Source

impl PartialOrd for LineBreak

1.10.0 (const: unstable) · Source

impl PartialOrd for Location<'_>

Source

impl PartialOrd for NumericType

1.0.0 (const: unstable) · Source

impl PartialOrd for Ordering

1.0.0 · Source

impl PartialOrd for OsStr

1.0.0 · Source

impl PartialOrd for OsString

Source

impl PartialOrd for Other

1.0.0 · Source

impl PartialOrd for Path

1.0.0 · Source

impl PartialOrd for PathBuf

1.33.0 · Source

impl PartialOrd for PhantomPinned

Source

impl PartialOrd for PotentialCodePoint

Source

impl PartialOrd for PotentialUtf8

Source

impl PartialOrd for PotentialUtf16

Source

impl PartialOrd for Private

Source

impl PartialOrd for Ready

Source

impl PartialOrd for Region

Source

impl PartialOrd for icu_locale_core::subtags::script::Script

Source

impl PartialOrd for icu_properties::props::Script

Source

impl PartialOrd for SentenceBreak

Source

impl PartialOrd for SigId

1.0.0 · Source

impl PartialOrd for SocketAddr

1.0.0 · Source

impl PartialOrd for SocketAddrV4

1.0.0 · Source

impl PartialOrd for SocketAddrV6

1.0.0 · Source

impl PartialOrd for String

Source

impl PartialOrd for SubdivisionId

Source

impl PartialOrd for SubdivisionSuffix

Source

impl PartialOrd for icu_locale_core::extensions::private::other::Subtag

Source

impl PartialOrd for icu_locale_core::subtags::Subtag

1.8.0 · Source

impl PartialOrd for SystemTime

Source

impl PartialOrd for Token

1.0.0 · Source

impl PartialOrd for TypeId

Source

impl PartialOrd for UnixTime

Source

impl PartialOrd for Url

URLs compare like their serialization.

Source

impl PartialOrd for icu_locale_core::extensions::transform::value::Value

Source

impl PartialOrd for icu_locale_core::extensions::unicode::value::Value

Source

impl PartialOrd for Variant

Source

impl PartialOrd for VariantId

Source

impl PartialOrd for Variants

Source

impl PartialOrd for VerticalOrientation

Source

impl PartialOrd for WordBreak

Source

impl PartialOrd for XmlVersion

1.0.0 (const: unstable) · Source

impl PartialOrd for bool

1.0.0 (const: unstable) · Source

impl PartialOrd for char

1.0.0 (const: unstable) · Source

impl PartialOrd for f16

1.0.0 (const: unstable) · Source

impl PartialOrd for f32

1.0.0 (const: unstable) · Source

impl PartialOrd for f64

Source

impl PartialOrd for f16b

1.0.0 (const: unstable) · Source

impl PartialOrd for f128

1.0.0 (const: unstable) · Source

impl PartialOrd for i8

1.0.0 (const: unstable) · Source

impl PartialOrd for i16

1.0.0 (const: unstable) · Source

impl PartialOrd for i32

1.0.0 (const: unstable) · Source

impl PartialOrd for i64

1.0.0 (const: unstable) · Source

impl PartialOrd for i128

1.0.0 (const: unstable) · Source

impl PartialOrd for isize

1.0.0 (const: unstable) · Source

impl PartialOrd for str

Implements comparison operations on strings.

Strings are compared lexicographically by their byte values. This compares Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Comparing strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl PartialOrd for u8

1.0.0 (const: unstable) · Source

impl PartialOrd for u16

1.0.0 (const: unstable) · Source

impl PartialOrd for u32

1.0.0 (const: unstable) · Source

impl PartialOrd for u64

1.0.0 (const: unstable) · Source

impl PartialOrd for u128

1.0.0 (const: unstable) · Source

impl PartialOrd for usize

Source

impl PartialOrd<&ByteStr> for ByteString

Source

impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>

Source

impl PartialOrd<&ByteStr> for Cow<'_, [u8]>

Source

impl PartialOrd<&ByteStr> for Cow<'_, str>

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&OsStr> for OsString

1.8.0 · Source

impl PartialOrd<&OsStr> for Path

1.8.0 · Source

impl PartialOrd<&OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<&Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<&Path> for OsStr

1.8.0 · Source

impl PartialOrd<&Path> for OsString

1.8.0 · Source

impl PartialOrd<&Path> for PathBuf

Source

impl PartialOrd<ByteStr> for ByteString

Source

impl PartialOrd<ByteString> for &ByteStr

Source

impl PartialOrd<ByteString> for ByteStr

Source

impl PartialOrd<ByteString> for Cow<'_, ByteStr>

Source

impl PartialOrd<ByteString> for Cow<'_, [u8]>

Source

impl PartialOrd<ByteString> for Cow<'_, str>

Source

impl PartialOrd<Bytes> for &[u8]

Source

impl PartialOrd<Bytes> for &str

Source

impl PartialOrd<Bytes> for String

Source

impl PartialOrd<Bytes> for Vec<u8>

Source

impl PartialOrd<Bytes> for [u8]

Source

impl PartialOrd<Bytes> for str

Source

impl PartialOrd<BytesMut> for &[u8]

Source

impl PartialOrd<BytesMut> for &str

Source

impl PartialOrd<BytesMut> for String

Source

impl PartialOrd<BytesMut> for Vec<u8>

Source

impl PartialOrd<BytesMut> for [u8]

Source

impl PartialOrd<BytesMut> for str

Source

impl PartialOrd<Cow<'_, ByteStr>> for &ByteStr

Source

impl PartialOrd<Cow<'_, ByteStr>> for ByteString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for &Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for Path

1.8.0 · Source

impl PartialOrd<Cow<'_, OsStr>> for PathBuf

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for &Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsStr

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for OsString

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for Path

1.8.0 · Source

impl PartialOrd<Cow<'_, Path>> for PathBuf

Source

impl PartialOrd<Cow<'_, [u8]>> for &ByteStr

Source

impl PartialOrd<Cow<'_, [u8]>> for ByteString

Source

impl PartialOrd<Cow<'_, str>> for &ByteStr

Source

impl PartialOrd<Cow<'_, str>> for ByteString

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv4Addr

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv6Addr

1.16.0 · Source

impl PartialOrd<Ipv4Addr> for IpAddr

1.16.0 · Source

impl PartialOrd<Ipv6Addr> for IpAddr

Source

impl PartialOrd<Level> for LevelFilter

Source

impl PartialOrd<LevelFilter> for Level

1.8.0 · Source

impl PartialOrd<OsStr> for &Path

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsStr> for OsString

1.8.0 · Source

impl PartialOrd<OsStr> for Path

1.8.0 · Source

impl PartialOrd<OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<OsString> for &OsStr

1.8.0 · Source

impl PartialOrd<OsString> for &Path

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<OsString> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<OsString> for OsStr

1.8.0 · Source

impl PartialOrd<OsString> for Path

1.8.0 · Source

impl PartialOrd<OsString> for PathBuf

1.8.0 · Source

impl PartialOrd<Path> for &OsStr

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<Path> for OsStr

1.8.0 · Source

impl PartialOrd<Path> for OsString

1.8.0 · Source

impl PartialOrd<Path> for PathBuf

1.8.0 · Source

impl PartialOrd<PathBuf> for &OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for &Path

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialOrd<PathBuf> for Cow<'_, Path>

1.8.0 · Source

impl PartialOrd<PathBuf> for OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for OsString

1.8.0 · Source

impl PartialOrd<PathBuf> for Path

Source

impl PartialOrd<PotentialCodePoint> for char

Source

impl PartialOrd<PotentialUtf8> for str

Source

impl PartialOrd<String> for Bytes

Source

impl PartialOrd<String> for BytesMut

Source

impl PartialOrd<Vec<u8>> for Bytes

Source

impl PartialOrd<Vec<u8>> for BytesMut

Source

impl PartialOrd<[u8]> for Bytes

Source

impl PartialOrd<[u8]> for BytesMut

Source

impl PartialOrd<char> for PotentialCodePoint

Source

impl PartialOrd<str> for Bytes

Source

impl PartialOrd<str> for BytesMut

1.0.0 · Source

impl PartialOrd<str> for OsStr

1.0.0 · Source

impl PartialOrd<str> for OsString

Source

impl PartialOrd<str> for PotentialUtf8

1.0.0 · Source

impl<'a, B> PartialOrd for Cow<'a, B>
where B: PartialOrd + ToOwned + ?Sized,

Source

impl<'a, T, F> PartialOrd for VarZeroVec<'a, T, F>

Source

impl<'a, T> PartialOrd for ZeroVec<'a, T>
where T: AsULE + PartialOrd,

Source

impl<'a, T> PartialOrd<&'a T> for Bytes
where Bytes: PartialOrd<T>, T: ?Sized,

Source

impl<'a, T> PartialOrd<&'a T> for BytesMut
where BytesMut: PartialOrd<T>, T: ?Sized,

Source

impl<'a, V> PartialOrd for VarZeroCow<'a, V>
where V: VarULE + PartialOrd + ?Sized,

1.0.0 · Source

impl<'a> PartialOrd for Component<'a>

1.0.0 · Source

impl<'a> PartialOrd for Components<'a>

Source

impl<'a> PartialOrd for Metadata<'a>

Source

impl<'a> PartialOrd for MetadataBuilder<'a>

Source

impl<'a> PartialOrd for PhantomContravariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomCovariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> PartialOrd for Prefix<'a>

1.0.0 · Source

impl<'a> PartialOrd for PrefixComponent<'a>

Source

impl<A, B, C, D, E, F, Format> PartialOrd for Tuple6VarULE<A, B, C, D, E, F, Format>

Source

impl<A, B, C, D, E, F> PartialOrd for Tuple6ULE<A, B, C, D, E, F>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE, D: PartialOrd + ULE, E: PartialOrd + ULE, F: PartialOrd + ULE,

Source

impl<A, B, C, D, E, Format> PartialOrd for Tuple5VarULE<A, B, C, D, E, Format>

Source

impl<A, B, C, D, E> PartialOrd for Tuple5ULE<A, B, C, D, E>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE, D: PartialOrd + ULE, E: PartialOrd + ULE,

Source

impl<A, B, C, D, Format> PartialOrd for Tuple4VarULE<A, B, C, D, Format>

Source

impl<A, B, C, D> PartialOrd for Tuple4ULE<A, B, C, D>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE, D: PartialOrd + ULE,

Source

impl<A, B, C, Format> PartialOrd for Tuple3VarULE<A, B, C, Format>

Source

impl<A, B, C> PartialOrd for Tuple3ULE<A, B, C>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE,

Source

impl<A, B, Format> PartialOrd for Tuple2VarULE<A, B, Format>
where A: PartialOrd + VarULE + ?Sized, B: PartialOrd + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B> PartialOrd for Tuple2ULE<A, B>
where A: PartialOrd + ULE, B: PartialOrd + ULE,

Source

impl<A, B> PartialOrd for VarTuple<A, B>
where A: PartialOrd, B: PartialOrd,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&B> for &A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&mut B> for &mut A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

Source

impl<A, V> PartialOrd for VarTupleULE<A, V>
where A: PartialOrd + AsULE, V: PartialOrd + VarULE + ?Sized, <A as AsULE>::ULE: PartialOrd,

Source

impl<A> PartialOrd for SmallVec<A>
where A: Array, <A as Array>::Item: PartialOrd,

Source

impl<Dyn> PartialOrd for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> PartialOrd for F
where F: FnPtr,

1.0.0 · Source

impl<K, V, A> PartialOrd for BTreeMap<K, V, A>

Source

impl<K, V, S> PartialOrd for LiteMap<K, V, S>
where K: PartialOrd + ?Sized, V: PartialOrd + ?Sized, S: PartialOrd,

1.41.0 · Source

impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
where Ptr: Deref, Q: Deref, <Ptr as Deref>::Target: PartialOrd<<Q as Deref>::Target>,

Source

impl<S> PartialOrd for Host<S>
where S: PartialOrd,

1.0.0 · Source

impl<T, A1, A2> PartialOrd<Vec<T, A2>> for Vec<T, A1>
where T: PartialOrd, A1: Allocator, A2: Allocator,

Implements comparison of vectors, lexicographically.

1.0.0 · Source

impl<T, A> PartialOrd for Arc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for BTreeSet<T, A>

1.0.0 · Source

impl<T, A> PartialOrd for Box<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for LinkedList<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Rc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueArc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueRc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for VecDeque<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 (const: unstable) · Source

impl<T, E> PartialOrd for Result<T, E>
where T: PartialOrd, E: PartialOrd,

Source

impl<T, F> PartialOrd for VarZeroSlice<T, F>

1.101.0 (const: unstable) · Source

impl<T, U> PartialOrd<SyncView<U>> for SyncView<T>
where T: Sync + PartialOrd<U> + ?Sized, U: Sync + ?Sized,

Source

impl<T, const N: usize> PartialOrd for Mask<T, N>

Source

impl<T, const N: usize> PartialOrd for Simd<T, N>

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

1.0.0 (const: unstable) · Source

impl<T, const N: usize> PartialOrd for [T; N]
where T: PartialOrd,

Implements comparison of arrays lexicographically.

Source

impl<T, const VARIANT: u32, const FIELD: u32> PartialOrd for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for (T₁, T₂, …, Tₙ)
where T: PartialOrd,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> PartialOrd for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*const T>::addr method.

1.0.0 · Source

impl<T> PartialOrd for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.10.0 · Source

impl<T> PartialOrd for Cell<T>
where T: PartialOrd + Copy,

Source

impl<T> PartialOrd for LossyWrap<T>
where T: PartialOrd,

1.20.0 · Source

impl<T> PartialOrd for ManuallyDrop<T>
where T: PartialOrd + ?Sized,

1.25.0 · Source

impl<T> PartialOrd for NonNull<T>
where T: ?Sized,

1.28.0 (const: unstable) · Source

impl<T> PartialOrd for NonZero<T>

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for Option<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> PartialOrd for PhantomData<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomInvariant<T>
where T: ?Sized,

1.36.0 · Source

impl<T> PartialOrd for Poll<T>
where T: PartialOrd,

1.10.0 · Source

impl<T> PartialOrd for RefCell<T>
where T: PartialOrd + ?Sized,

1.19.0 (const: unstable) · Source

impl<T> PartialOrd for Reverse<T>
where T: PartialOrd,

1.74.0 · Source

impl<T> PartialOrd for Saturating<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for TryWriteableInfallibleAsWriteable<T>
where T: PartialOrd,

1.0.0 · Source

impl<T> PartialOrd for Wrapping<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for WriteableAsTryWriteableInfallible<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for ZeroSlice<T>
where T: AsULE + PartialOrd,

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for [T]
where T: PartialOrd,

Implements comparison of slices lexicographically.

Source

impl<U, const N: usize> PartialOrd for NichedOption<U, N>
where U: PartialOrd,

Source

impl<U> PartialOrd for OptionVarULE<U>
where U: VarULE + PartialOrd + ?Sized,

Source

impl<Y, C> PartialOrd for Yoke<Y, C>
where Y: for<'a> Yokeable<'a>, <Y as Yokeable<'a>>::Output: for<'a> PartialOrd,

Source

impl<Y, R> PartialOrd for CoroutineState<Y, R>
where Y: PartialOrd, R: PartialOrd,

Source

impl<const N: usize> PartialOrd for RawBytesULE<N>

Source

impl<const N: usize> PartialOrd for TinyAsciiStr<N>

Source

impl<const N: usize> PartialOrd for UnvalidatedTinyAsciiStr<N>