Struct Tape

pub struct Tape<'input>(pub Vec<Node<'input>>);
Tape

Tuple Fields

0: Vec<Node<'input>>

Implementations

Source

impl<'input> Tape<'input>

pub fn as_value(&self) -> Value<'_, 'input>

Turns the tape into a Value that can be used like a value_trait::Value

pub fn null() -> Tape<'input>

Creates an empty tape with a null element in it

pub fn reset<'new>(self) -> Tape<'new>

Clears the tape and returns it with a new lifetime to allow re-using the already allocated buffer.

pub fn deserialize<T>(self) -> Result<T, Error>
where T: Deserialize<'input>,

Deserializes the tape into a type that implements serde::Deserialize

Errors

Returns an error if the deserialization fails