Module value

simd-json JSON-DOM value

Modules

borrowed
This module holds the two dom implementations we use.
lazy
Lazy value, uses a tape until mutated.
owned
Owned, lifetimeless version of the value for times when lifetimes are to be avoided
tape
Tape implementation

Structs

TryTypeError
A type error thrown by the try_* functions

Enums

AccessError
An access error for ValueType
BorrowedValue
Borrowed JSON-DOM Value, consider using the ValueTrait to access its content
ExtendedValueType
Extended types that have no native representation in JSON
OwnedValue
Owned JSON-DOM Value, consider using the ValueTrait to access it’s content. This is slower then the BorrowedValue as a tradeoff for getting rid of lifetimes.
StaticNode
Static tape node
ValueType
Types of JSON values

Traits

ValueBuilder
Support of builder methods for traits.

Functions

deserialize
Parses a slice of bytes into a Value dom.
deserialize_with_buffers
Parses a slice of bytes into a Value dom.
to_borrowed_value
Parses a slice of bytes into a Value dom.
to_borrowed_value_with_buffers
Parses a slice of bytes into a Value dom.
to_owned_value
Parses a slice of bytes into a Value dom.
to_owned_value_with_buffers
Parses a slice of bytes into a Value dom.

Type Aliases

ObjectHasher
Hasher used for objects