Function to_borrowed_value

pub fn to_borrowed_value(s: &mut [u8]) -> Result<Value<'_>, Error>
Parses a slice of bytes into a Value dom.

This function will rewrite the slice to de-escape strings. As we reference parts of the input slice the resulting dom has the same lifetime as the slice it was created from.

Errors

Will return Err if s is invalid JSON.