Enum Object

pub enum Object<'borrow, 'tape, 'input> {
    Tape(Object<'tape, 'input>),
    Value(&'borrow SizedHashMap<Cow<'input, str>, Value<'input>>),
}
Wrapper around the tape that allows interacting with it via a Object-like API.

Variants



Tape(Object<'tape, 'input>)

Tape variant



Value(&'borrow SizedHashMap<Cow<'input, str>, Value<'input>>)

Value variant

Implementations

Source

impl<'tape, 'input> Object<'_, 'tape, 'input>

pub fn get<'a, Q>(&'a self, k: &Q) -> Option<Value<'a, 'tape, 'input>>
where str: Borrow<Q>, Cow<'b, str>: for<'b> Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Gets a ref to a value based on a key, returns None if the current Value isn’t an Object or doesn’t contain the key it was asked for.

pub fn iter<'i>(&'i self) -> Iter<'i, 'tape, 'input>

Iterates over the key value paris

pub fn keys<'i>(&'i self) -> Keys<'i, 'tape, 'input>

Iterates over the keys

pub fn values<'i>(&'i self) -> Values<'i, 'tape, 'input>

Iterates over the values

pub fn len(&self) -> usize

Number of key/value pairs

pub fn is_empty(&self) -> bool

Returns if the object is empty