Struct Object

pub struct Object<'tape, 'input>(/* private fields */);
Wrapper around the tape that allows interacting with it via a Object-like API.

Implementations

Source

impl<'tape, 'input> Object<'tape, 'input>

pub fn get<Q>(&self, k: &Q) -> Option<Value<'tape, 'input>>
where str: Borrow<Q> + Hash + Eq, Q: Hash + Eq + Ord + ?Sized,

Gets a ref to a value based on a key, returns None if the current Value isn’t an Object or doesn’t contain the key it was asked for.

pub fn iter<'i>(&'i self) -> Iter<'tape, 'input>

Iterates over the key value paris

pub fn keys<'i>(&'i self) -> Keys<'tape, 'input>

Iterates over the keys

pub fn values<'i>(&'i self) -> Values<'tape, 'input>

Iterates over the values

pub fn len(&self) -> usize

Number of key/value pairs

pub fn is_empty(&self) -> bool

Returns if the object is empty