Index

Trait Index 

pub trait Index: Sealed { }
A type that can be used to index into a serde_json::Value.

The get and get_mut methods of Value accept any type that implements Index, as does the square-bracket indexing operator. This trait is implemented for strings which are used as the index into a JSON map, and for usize which is used as the index into a JSON array.

This trait is sealed and cannot be implemented for types outside of serde_json.

Examples

let data = json!({ "inner": [1, 2, 3] });

// Data is a JSON map so it can be indexed with a string.
let inner = &data["inner"];

// Inner is a JSON array so it can be indexed with an integer.
let first = &inner[0];

assert_eq!(first, 1);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Index for str

Source

impl Index for usize

Source

impl Index for String

Source

impl<T> Index for &T
where T: Index + ?Sized,

Implementors