Crate http_request

Structs

Enums

Traits

Type Aliases

  • Type alias for a boxed trait object implementing RequestTrait
  • A type alias for a boxed dynamic trait object implementing the ResponseTrait trait.