simd-json JSON-DOM value
Modules
- borrowed
- This module holds the two dom implementations we use.
- lazy
- Lazy value, uses a tape until mutated.
- owned
- Owned, lifetimeless version of the value for times when lifetimes are to be avoided
- tape
- Tape implementation
Structs
- TryType
Error - A type error thrown by the
try_*functions
Enums
- Access
Error - An access error for
ValueType - Borrowed
Value - Borrowed JSON-DOM Value, consider using the
ValueTraitto access its content - Extended
Value Type - Extended types that have no native representation in JSON
- Owned
Value - Owned JSON-DOM Value, consider using the
ValueTraitto access it’s content. This is slower then theBorrowedValueas a tradeoff for getting rid of lifetimes. - Static
Node - Static tape node
- Value
Type - Types of JSON values
Traits
- Value
Builder - Support of builder methods for traits.
Functions
- deserialize
- Parses a slice of bytes into a Value dom.
- deserialize_
with_ buffers - Parses a slice of bytes into a Value dom.
- to_
borrowed_ value - Parses a slice of bytes into a Value dom.
- to_
borrowed_ value_ with_ buffers - Parses a slice of bytes into a Value dom.
- to_
owned_ value - Parses a slice of bytes into a Value dom.
- to_
owned_ value_ with_ buffers - Parses a slice of bytes into a Value dom.
Type Aliases
- Object
Hasher - Hasher used for objects